@@ -21,6 +21,7 @@ class Create(operation.Create):
     def pre(self, session, **kwargs):
         self.role = self.manager.api.roles().get_role_by_name(
             role_name=Role.USER)
+        kwargs.pop('settings', None)
         return super().pre(session, **kwargs)
 
     def do(self, session, **kwargs):
@@ -30,6 +31,13 @@ class Create(operation.Create):
         return self.entity
 
 
+class Update(operation.Update):
+
+    def do(self, session, **kwargs):
+        kwargs.pop('settings', None)
+        return super().do(session, **kwargs)
+
+
 class UpdatePassword(operation.Update):
 
     def _check_password(self, password, password_db):
@@ -296,6 +304,7 @@ class Manager(manager.Manager):
     def __init__(self, driver):
         super(Manager, self).__init__(driver)
         self.create = Create(self)
+        self.update = Update(self)
         self.update_password = UpdatePassword(self)
         self.restore = Restore(self)
         self.reset = Reset(self)
